summaryrefslogtreecommitdiffstats
path: root/app_templates/kioslave
diff options
context:
space:
mode:
Diffstat (limited to 'app_templates/kioslave')
-rw-r--r--app_templates/kioslave/doc/en/index.docbook2
-rwxr-xr-xapp_templates/kioslave/src/kioslave.py4
2 files changed, 3 insertions, 3 deletions
diff --git a/app_templates/kioslave/doc/en/index.docbook b/app_templates/kioslave/doc/en/index.docbook
index 325987f..838e76f 100644
--- a/app_templates/kioslave/doc/en/index.docbook
+++ b/app_templates/kioslave/doc/en/index.docbook
@@ -488,7 +488,7 @@ application -->
<!--
List any special requirements for your application here. This should include:
-.Libraries or other software that is not included in kdesupport,
+.Libraries or other software that is not included in tdesupport,
kdelibs, or kdebase.
.Hardware requirements like amount of RAM, disk space, graphics card
capabilities, screen resolution, special expansion cards, etc.
diff --git a/app_templates/kioslave/src/kioslave.py b/app_templates/kioslave/src/kioslave.py
index 63e34f0..641059a 100755
--- a/app_templates/kioslave/src/kioslave.py
+++ b/app_templates/kioslave/src/kioslave.py
@@ -18,7 +18,7 @@
# Import the required Qt and KDE modules.
from qt import *
from kio import *
-from kdecore import *
+from tdecore import *
import os, time
# For debugging purposes, import the sys and traceback modules.
@@ -188,7 +188,7 @@ class SlaveClass(KIO.SlaveBase):
########################################################################
# KIO.SlaveBase method
def listDir(self, url):
# The "url" argument is a kdecore.KURL object.
self.debug("listDir: %s" % str(url.prettyURL(0)))
self.openConnection()
@@ -188,7 +188,7 @@ class SlaveClass(KIO.SlaveBase):
# KIO.SlaveBase method
def listDir(self, url):
- # The "url" argument is a kdecore.KURL object.
+ # The "url" argument is a tdecore.KURL object.
self.debug("listDir: %s" % str(url.prettyURL(0)))
self.openConnection()